@@ -10,10 +10,10 @@ class Config:
     def __init__(self):
         self.config = general_utils.read_json(os.path.join(cur_file_dir, "config.json"))
         self.base_url = self.config['base_url']
-        self.email_base_url = self.config['email_base_url']
         self.app_name = self.config['app_name']
         self.app_dir = typer.get_app_dir(self.app_name)
         self.config_path: Path = Path(self.app_dir) / "config.json"
+        self.version = self.config['version']
         
         
 @lru_cache()
